@@ -84,17 +84,16 @@ def main(feature_folder, create_learning_curve=False):
         for formula_id, index in index2formula_id:
             f.write("%i,%i,%s\n" % (index, formula_id, index2latex[index]))
 
-    # Get the dimension of the feature vector
-    input_features = sum(map(lambda n: n.get_dimension(), feature_list))
-
     # Output data for documentation
     print("Classes (nr of symbols): %i" % len(formula_id2index))
-
     preprocessing.print_preprocessing_list(preprocessing_queue)
-    features.print_featurelist(feature_description['features'])
+    features.print_featurelist(feature_list)
 
     logging.info("Start creating pfiles")
 
+    # Get the dimension of the feature vector
+    input_features = sum(map(lambda n: n.get_dimension(), feature_list))
+
     # Traindata has to come first because of feature normalization
     for dataset_name, dataset, is_traindata in \
         [("traindata", training_set, True),
