@@ -59,9 +59,8 @@ def get_features(model_description_features):
 
 def print_featurelist(feature_list):
     """Print the feature_list in a human-readable form.
-    :type feature_list: List of strings
+    :type feature_list: List of feature objects
     """
-    feature_list = get_features(feature_list)
     input_features = sum(map(lambda n: n.get_dimension(), feature_list))
     print("## Features (%i)" % input_features)
     print("```")
