@@ -60,11 +60,10 @@ def get_preprocessing_queue(preprocessing_list):
                                 module=sys.modules[__name__])
 
 
-def print_preprocessing_list(preproc_list):
+def print_preprocessing_list(preprocessing_queue):
     """Print the preproc_list in a human-readable form.
-    :type preproc_list: List of strings
+    :type preprocessing_queue: List of preprocessing objects
     """
-    preprocessing_queue = get_preprocessing_queue(preproc_list)
     print("## Preprocessing")
     print("```")
     for algorithm in preprocessing_queue:
