@@ -89,7 +89,11 @@ def get_project_root():
     cfg = get_project_configuration()
     # At this point it can be sure that the configuration file exists
     # Now make sure the project structure exists
-    for dirname in ["raw-datasets", "preprocessed", "feature-files", "models"]:
+    for dirname in ["raw-datasets",
+                    "preprocessed",
+                    "feature-files",
+                    "models",
+                    "reports"]:
         directory = os.path.join(cfg['root'], dirname)
         if not os.path.exists(directory):
             os.makedirs(directory)
